// Version information used while compiling samtools, bcftools, and htslib

#define SAMTOOLS_VERSION "1.15.1 (pysam)"
#define BCFTOOLS_VERSION "1.15.1 (pysam)"
#define HTS_VERSION_TEXT "1.15.1 (pysam)"
